@@ -299,8 +299,11 @@ providers_list = {
         r'mangarave\.com/manga/.',
         r'thetopcomic\.com/manga/.',
     ],
-    'jaiminisbox_com': [
-        r'jaiminisbox\.com/reader/series/.',
+    # 'jaiminisbox_com': [
+    #     r'jaiminisbox\.com/reader/series/.',
+    # ],
+    'jaiminisbox_net': [
+        r'jaiminisbox\.net/manga/.',
     ],
     'japscan_com': [
         r'japscan\.(cc|com|co|to|se)/.',
@@ -342,6 +345,9 @@ providers_list = {
         r'read\.lhtranslation\.com/(truyen|manga)-.',
         r'lhtranslation\.net/(truyen|manga)-.',
     ],
+    'littlexgarden_com': [
+        r'littlexgarden\.com/(?!mangas|infos|likes|notifications)'
+    ],
     'lolibooru_moe': [
         r'lolibooru\.moe/post.',
     ],
@@ -450,6 +456,10 @@ providers_list = {
     'mangamew_com_vn': [
         r'mangamew\.com/(\w+-)?truyen/.',
     ],
+    'manganato_com': [
+        r'manganato\.com/manga-',
+        r'readmanganato\.com/manga-',
+    ],
     'manganelo_com': [
         r'manganelo\.com/(manga|chapter)/.',
     ],
